@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1993-2020 The Octave Project Developers
+// Copyright (C) 1993-2021 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -133,10 +133,10 @@ Compute the inverse cosine in radians for each element of @var{x}.
 %! v = [0, pi, pi/2, pi/2];
 %! assert (real (acos (x)), v);
 
-%!xtest <*52627>
+%!xtest <52627>
 %! ## Same test code as above, but intended only for test statistics on Mac and
 %! ## Windows.  Their trig/hyperbolic functions have huge tolerances.
-%! if (! ismac ()), return; endif
+%! if (! ismac () && ! ispc ()), return; endif
 %! x = [1, -1, i, -i] .* 1e150;
 %! v = [0, pi, pi/2, pi/2];
 %! assert (real (acos (x)), v);
@@ -208,10 +208,10 @@ Compute the inverse hyperbolic cosine for each element of @var{x}.
 %! v = [0, pi, pi/2, -pi/2];
 %! assert (imag (acosh (x)), v);
 
-%!xtest <*52627>
+%!xtest <52627>
 %! ## Same test code as above, but intended only for test statistics on Mac and
 %! ## Windows.  Their trig/hyperbolic functions have huge tolerances.
-%! if (! ismac ()), return; endif
+%! if (! ismac () && ! ispc ()), return; endif
 %! x = [1, -1, i, -i] .* 1e150;
 %! v = [0, pi, pi/2, -pi/2];
 %! assert (imag (acosh (x)), v);
@@ -322,12 +322,18 @@ Compute the inverse sine in radians for each element of @var{x}.
 %! ival = 1.31695789692481635;
 %! obs = asin ([2, 2-i*eps, 2+i*eps]);
 %! exp = [rval - ival*i, rval - ival*i, rval + ival*i];
-%! assert (obs, exp, 2*eps);
+%! if (ismac ())
+%!   ## Math libraries on macOS seem to implement asin with less accuracy.
+%!   tol = 6*eps;
+%! else
+%!   tol = 2*eps;
+%! endif
+%! assert (obs, exp, tol);
 %! obs = asin ([-2, -2-i*eps, -2+i*eps]);
 %! exp = [-rval + ival*i, -rval - ival*i, -rval + ival*i];
-%! assert (obs, exp, 2*eps);
-%! assert (asin ([2 0]),  [rval - ival*i, 0], 2*eps);
-%! assert (asin ([2 0i]), [rval - ival*i, 0], 2*eps);
+%! assert (obs, exp, tol);
+%! assert (asin ([2 0]),  [rval - ival*i, 0], tol);
+%! assert (asin ([2 0i]), [rval - ival*i, 0], tol);
 
 ## Test large magnitude arguments (bug #45507)
 ## Test fails with older versions of libm, solution is to upgrade.
@@ -336,10 +342,10 @@ Compute the inverse sine in radians for each element of @var{x}.
 %! v = [pi/2, -pi/2, 0, -0];
 %! assert (real (asin (x)), v);
 
-%!xtest <*52627>
+%!xtest <52627>
 %! ## Same test code as above, but intended only for test statistics on Mac and
 %! ## Windows. Their trig/hyperbolic functions have huge tolerances.
-%! if (! ismac ()), return; endif
+%! if (! ismac () && ! ispc ()), return; endif
 %! x = [1, -1, i, -i] .* 1e150;
 %! v = [pi/2, -pi/2, 0, -0];
 %! assert (real (asin (x)), v);
@@ -379,10 +385,10 @@ Compute the inverse hyperbolic sine for each element of @var{x}.
 %! v = [0, 0, pi/2, -pi/2];
 %! assert (imag (asinh (x)), v);
 
-%!xtest <*52627>
+%!xtest <52627>
 %! ## Same test code as above, but intended only for test statistics on Mac and
 %! ## Windows.  Their trig/hyperbolic functions have huge tolerances.
-%! if (! ismac ()), return; endif
+%! if (! ismac () && ! ispc ()), return; endif
 %! x = [1, -1, i, -i] .* 1e150;
 %! v = [0, 0, pi/2, -pi/2];
 %! assert (imag (asinh (x)), v);
