@@ -1,30 +1,34 @@
-/*
-
-Copyright (C) 1996-2018 John W. Eaton
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 1996-2021 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
 #endif
 
-#include <iostream>
+#include <istream>
+#include <ostream>
 
 #include "Cell.h"
 #include "builtin-defun-decls.h"
@@ -59,6 +63,18 @@ static int Vstruct_levels_to_print = 2;
 // specified by struct_levels_to_print.
 static bool Vprint_struct_array_contents = false;
 
+void
+octave_struct::break_closure_cycles (const std::shared_ptr<octave::stack_frame>& frame)
+{
+  for (octave_idx_type j = 0; j < map.nfields (); j++)
+    {
+      Cell& c = map.contents (j);
+
+      for (octave_idx_type i = 0; i < c.numel (); i++)
+        c(i).break_closure_cycles (frame);
+    }
+}
+
 octave_base_value *
 octave_struct::try_narrowing_conversion (void)
 {
@@ -107,7 +123,7 @@ err_invalid_index_type (const std::string& nm, char t)
 static void
 maybe_warn_invalid_field_name (const std::string& key, const char *who)
 {
-  if (! valid_identifier (key))
+  if (! octave::valid_identifier (key))
     {
       if (who)
         warning_with_id ("Octave:language-extension",
@@ -135,13 +151,16 @@ octave_struct::subsref (const std::string& type,
       {
         if (type.length () > 1 && type[1] == '.')
           {
-            std::list<octave_value_list>::const_iterator p = idx.begin ();
+            auto p = idx.begin ();
             octave_value_list key_idx = *++p;
 
             const Cell tmp = dotref (key_idx);
 
             const Cell t = tmp.index (idx.front ());
 
+            // Avoid creating a comma-separated list if the result is a
+            // single element.
+
             retval(0) = (t.numel () == 1) ? t(0) : octave_value (t, true);
 
             // We handled two index elements, so tell
@@ -156,12 +175,12 @@ octave_struct::subsref (const std::string& type,
 
     case '.':
       {
-        if (map.numel () > 0)
-          {
-            const Cell t = dotref (idx.front ());
+        const Cell t = dotref (idx.front ());
 
-            retval(0) = (t.numel () == 1) ? t(0) : octave_value (t, true);
-          }
+        // Avoid creating a comma-separated list if the result is a
+        // single element.
+
+        retval(0) = (t.numel () == 1) ? t(0) : octave_value (t, true);
       }
       break;
 
@@ -198,13 +217,16 @@ octave_struct::subsref (const std::string& type,
       {
         if (type.length () > 1 && type[1] == '.')
           {
-            std::list<octave_value_list>::const_iterator p = idx.begin ();
+            auto p = idx.begin ();
             octave_value_list key_idx = *++p;
 
             const Cell tmp = dotref (key_idx, auto_add);
 
             const Cell t = tmp.index (idx.front (), auto_add);
 
+            // Avoid creating a comma-separated list if the result is a
+            // single element.
+
             retval = (t.numel () == 1) ? t(0) : octave_value (t, true);
 
             // We handled two index elements, so tell
@@ -223,6 +245,9 @@ octave_struct::subsref (const std::string& type,
           {
             const Cell t = dotref (idx.front (), auto_add);
 
+            // Avoid creating a comma-separated list if the result is a
+            // single element.
+
             retval = (t.numel () == 1) ? t(0) : octave_value (t, true);
           }
       }
@@ -291,7 +316,7 @@ octave_struct::subsasgn (const std::string& type,
           {
             if (type.length () > 1 && type[1] == '.')
               {
-                std::list<octave_value_list>::const_iterator p = idx.begin ();
+                auto p = idx.begin ();
                 octave_value_list t_idx = *p;
 
                 octave_value_list key_idx = *++p;
@@ -313,7 +338,7 @@ octave_struct::subsasgn (const std::string& type,
                 std::string next_type = type.substr (2);
 
                 Cell tmpc (1, 1);
-                octave_map::iterator pkey = map.seek (key);
+                auto pkey = map.seek (key);
                 if (pkey != map.end ())
                   {
                     map.contents (pkey).make_unique ();
@@ -365,7 +390,7 @@ octave_struct::subsasgn (const std::string& type,
             std::string next_type = type.substr (1);
 
             Cell tmpc (1, 1);
-            octave_map::iterator pkey = map.seek (key);
+            auto pkey = map.seek (key);
             if (pkey != map.end ())
               {
                 map.contents (pkey).make_unique ();
@@ -414,7 +439,7 @@ octave_struct::subsasgn (const std::string& type,
       {
         if (n > 1 && type[1] == '.')
           {
-            std::list<octave_value_list>::const_iterator p = idx.begin ();
+            auto p = idx.begin ();
             octave_value_list key_idx = *++p;
             octave_value_list idxf = idx.front ();
 
@@ -445,8 +470,7 @@ octave_struct::subsasgn (const std::string& type,
               }
             else
               {
-                const octave_map& cmap =
-                  const_cast<const octave_map &> (map);
+                const octave_map& cmap = const_cast<const octave_map &> (map);
                 // cast to const reference, avoid forced key insertion.
                 if (idxf.all_scalars ()
                     || cmap.contents (key).index (idxf, true).numel () == 1)
@@ -538,19 +562,22 @@ octave_value
 octave_struct::do_index_op (const octave_value_list& idx, bool resize_ok)
 {
   if (idx.length () == 0)
-    return map;
+    {
+      warn_empty_index (type_name ());
+      return map;
+    }
   else  // octave_map handles indexing itself.
     return map.index (idx, resize_ok);
 }
 
-size_t
+std::size_t
 octave_struct::byte_size (void) const
 {
   // Neglect the size of the fieldnames.
 
-  size_t retval = 0;
+  std::size_t retval = 0;
 
-  for (octave_map::const_iterator p = map.begin (); p != map.end (); p++)
+  for (auto p = map.cbegin (); p != map.cend (); p++)
     {
       std::string key = map.key (p);
 
@@ -765,8 +792,7 @@ octave_struct::load_ascii (std::istream& is)
           bool dummy;
 
           // recurse to read cell elements
-          std::string nm
-            = read_text_data (is, "", dummy, t2, j);
+          std::string nm = read_text_data (is, "", dummy, t2, j, false);
 
           if (! is)
             break;
@@ -790,7 +816,7 @@ octave_struct::load_ascii (std::istream& is)
 }
 
 bool
-octave_struct::save_binary (std::ostream& os, bool& save_as_floats)
+octave_struct::save_binary (std::ostream& os, bool save_as_floats)
 {
   octave_map m = map_value ();
 
@@ -1071,6 +1097,13 @@ octave_struct::fast_elem_insert (octave_idx_type n,
 DEFINE_OV_TYPEID_FUNCTIONS_AND_DATA(octave_scalar_struct, "scalar struct",
                                     "struct");
 
+void
+octave_scalar_struct::break_closure_cycles (const std::shared_ptr<octave::stack_frame>& frame)
+{
+  for (octave_idx_type i = 0; i < map.nfields (); i++)
+    map.contents(i).break_closure_cycles (frame);
+}
+
 octave_value
 octave_scalar_struct::dotref (const octave_value_list& idx, bool auto_add)
 {
@@ -1212,7 +1245,7 @@ octave_scalar_struct::subsasgn (const std::string& type,
           std::string next_type = type.substr (1);
 
           octave_value tmp;
-          octave_map::iterator pkey = map.seek (key);
+          auto pkey = map.seek (key);
           if (pkey != map.end ())
             {
               map.contents (pkey).make_unique ();
@@ -1257,14 +1290,14 @@ octave_scalar_struct::do_index_op (const octave_value_list& idx, bool resize_ok)
   return octave_map (map).index (idx, resize_ok);
 }
 
-size_t
+std::size_t
 octave_scalar_struct::byte_size (void) const
 {
   // Neglect the size of the fieldnames.
 
-  size_t retval = 0;
+  std::size_t retval = 0;
 
-  for (octave_map::const_iterator p = map.begin (); p != map.end (); p++)
+  for (auto p = map.cbegin (); p != map.cend (); p++)
     {
       std::string key = map.key (p);
 
@@ -1428,7 +1461,7 @@ octave_scalar_struct::load_ascii (std::istream& is)
 
           // recurse to read cell elements
           std::string nm
-            = read_text_data (is, "", dummy, t2, j);
+            = read_text_data (is, "", dummy, t2, j, false);
 
           if (! is)
             break;
@@ -1450,7 +1483,7 @@ octave_scalar_struct::load_ascii (std::istream& is)
 }
 
 bool
-octave_scalar_struct::save_binary (std::ostream& os, bool& save_as_floats)
+octave_scalar_struct::save_binary (std::ostream& os, bool save_as_floats)
 {
   octave_map m = map_value ();
 
@@ -2023,7 +2056,7 @@ A(1)
       if (! args(2).is_real_scalar ())
         error ("cell2struct: DIM must be a real scalar");
 
-      dim = (nargin == 2 ? 0 : args(2).int_value () - 1);
+      dim = args(2).int_value () - 1;
     }
 
   if (dim < 0)
