@@ -1,39 +1,41 @@
-/*
-
-Copyright (C) 1994-2016 John W. Eaton
-
-This file is part of Octave.
-
-Octave is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 3 of the License, or (at your
-option) any later version.
-
-Octave is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<http://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 1994-2021 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if ! defined (octave_fCMatrix_h)
 #define octave_fCMatrix_h 1
 
 #include "octave-config.h"
 
-#include "fCNDArray.h"
+#include "DET.h"
 #include "MArray.h"
 #include "MDiagArray2.h"
 #include "MatrixType.h"
-
+#include "fCNDArray.h"
 #include "mx-defs.h"
 #include "mx-op-decl.h"
 #include "oct-cmplx.h"
-#include "DET.h"
 
 class
 OCTAVE_API
@@ -58,7 +60,13 @@ public:
 
   typedef void (*solve_singularity_handler) (float rcon);
 
-  FloatComplexMatrix (void) : FloatComplexNDArray () { }
+  FloatComplexMatrix (void) = default;
+
+  FloatComplexMatrix (const FloatComplexMatrix& a) = default;
+
+  FloatComplexMatrix& operator = (const FloatComplexMatrix& a) = default;
+
+  ~FloatComplexMatrix (void) = default;
 
   FloatComplexMatrix (octave_idx_type r, octave_idx_type c)
     : FloatComplexNDArray (dim_vector (r, c)) { }
@@ -73,9 +81,6 @@ public:
   FloatComplexMatrix (const dim_vector& dv, const FloatComplex& val)
     : FloatComplexNDArray (dv.redim (2), val) { }
 
-  FloatComplexMatrix (const FloatComplexMatrix& a)
-    : FloatComplexNDArray (a) { }
-
   template <typename U>
   FloatComplexMatrix (const MArray<U>& a)
     : FloatComplexNDArray (a.as_matrix ()) { }
@@ -115,7 +120,7 @@ public:
   bool operator == (const FloatComplexMatrix& a) const;
   bool operator != (const FloatComplexMatrix& a) const;
 
-  bool is_hermitian (void) const;
+  bool ishermitian (void) const;
 
   // destructive insert/delete/reorder operations
 
@@ -193,10 +198,10 @@ public:
   }
 
 private:
-  FloatComplexMatrix tinverse (MatrixType &mattype, octave_idx_type& info,
+  FloatComplexMatrix tinverse (MatrixType& mattype, octave_idx_type& info,
                                float& rcon, bool force, bool calc_cond) const;
 
-  FloatComplexMatrix finverse (MatrixType &mattype, octave_idx_type& info,
+  FloatComplexMatrix finverse (MatrixType& mattype, octave_idx_type& info,
                                float& rcon, bool force, bool calc_cond) const;
 
 public:
@@ -205,9 +210,9 @@ public:
   FloatComplexMatrix inverse (octave_idx_type& info, float& rcon,
                               bool force = false, bool calc_cond = true) const;
 
-  FloatComplexMatrix inverse (MatrixType &mattype) const;
-  FloatComplexMatrix inverse (MatrixType &mattype, octave_idx_type& info) const;
-  FloatComplexMatrix inverse (MatrixType &mattype, octave_idx_type& info,
+  FloatComplexMatrix inverse (MatrixType& mattype) const;
+  FloatComplexMatrix inverse (MatrixType& mattype, octave_idx_type& info) const;
+  FloatComplexMatrix inverse (MatrixType& mattype, octave_idx_type& info,
                               float& rcon, bool force = false,
                               bool calc_cond = true) const;
 
@@ -223,77 +228,78 @@ public:
   FloatComplexDET determinant (octave_idx_type& info) const;
   FloatComplexDET determinant (octave_idx_type& info, float& rcon,
                                bool calc_cond = true) const;
-  FloatComplexDET determinant (MatrixType &mattype, octave_idx_type& info,
+  FloatComplexDET determinant (MatrixType& mattype, octave_idx_type& info,
                                float& rcon, bool calc_cond = true) const;
 
   float rcond (void) const;
-  float rcond (MatrixType &mattype) const;
+  float rcond (MatrixType& mattype) const;
 
 private:
   // Upper triangular matrix solvers
-  FloatComplexMatrix utsolve (MatrixType &typ, const FloatComplexMatrix& b,
+  FloatComplexMatrix utsolve (MatrixType& mattype, const FloatComplexMatrix& b,
                               octave_idx_type& info, float& rcon,
                               solve_singularity_handler sing_handler,
                               bool calc_cond = false,
                               blas_trans_type transt = blas_no_trans) const;
 
   // Lower triangular matrix solvers
-  FloatComplexMatrix ltsolve (MatrixType &typ, const FloatComplexMatrix& b,
+  FloatComplexMatrix ltsolve (MatrixType& mattype, const FloatComplexMatrix& b,
                               octave_idx_type& info, float& rcon,
                               solve_singularity_handler sing_handler,
                               bool calc_cond = false,
                               blas_trans_type transt = blas_no_trans) const;
 
   // Full matrix solvers (umfpack/cholesky)
-  FloatComplexMatrix fsolve (MatrixType &typ, const FloatComplexMatrix& b,
+  FloatComplexMatrix fsolve (MatrixType& mattype, const FloatComplexMatrix& b,
                              octave_idx_type& info, float& rcon,
                              solve_singularity_handler sing_handler,
                              bool calc_cond = false) const;
 
 public:
   // Generic interface to solver with no probing of type
-  FloatComplexMatrix solve (MatrixType &typ, const FloatMatrix& b) const;
-  FloatComplexMatrix solve (MatrixType &typ, const FloatMatrix& b,
+  FloatComplexMatrix solve (MatrixType& mattype, const FloatMatrix& b) const;
+  FloatComplexMatrix solve (MatrixType& mattype, const FloatMatrix& b,
                             octave_idx_type& info) const;
-  FloatComplexMatrix solve (MatrixType &typ, const FloatMatrix& b,
+  FloatComplexMatrix solve (MatrixType& mattype, const FloatMatrix& b,
                             octave_idx_type& info, float& rcon) const;
-  FloatComplexMatrix solve (MatrixType &typ, const FloatMatrix& b,
+  FloatComplexMatrix solve (MatrixType& mattype, const FloatMatrix& b,
                             octave_idx_type& info,
                             float& rcon, solve_singularity_handler sing_handler,
                             bool singular_fallback = true,
                             blas_trans_type transt = blas_no_trans) const;
 
-  FloatComplexMatrix solve (MatrixType &typ, const FloatComplexMatrix& b) const;
-  FloatComplexMatrix solve (MatrixType &typ, const FloatComplexMatrix& b,
+  FloatComplexMatrix solve (MatrixType& mattype,
+                            const FloatComplexMatrix& b) const;
+  FloatComplexMatrix solve (MatrixType& mattype, const FloatComplexMatrix& b,
                             octave_idx_type& info) const;
-  FloatComplexMatrix solve (MatrixType &typ, const FloatComplexMatrix& b,
+  FloatComplexMatrix solve (MatrixType& mattype, const FloatComplexMatrix& b,
                             octave_idx_type& info, float& rcon) const;
-  FloatComplexMatrix solve (MatrixType &typ, const FloatComplexMatrix& b,
+  FloatComplexMatrix solve (MatrixType& mattype, const FloatComplexMatrix& b,
                             octave_idx_type& info, float& rcon,
                             solve_singularity_handler sing_handler,
                             bool singular_fallback = true,
                             blas_trans_type transt = blas_no_trans) const;
 
-  FloatComplexColumnVector solve (MatrixType &typ,
+  FloatComplexColumnVector solve (MatrixType& mattype,
                                   const FloatColumnVector& b) const;
-  FloatComplexColumnVector solve (MatrixType &typ, const FloatColumnVector& b,
+  FloatComplexColumnVector solve (MatrixType& mattype, const FloatColumnVector& b,
                                   octave_idx_type& info) const;
-  FloatComplexColumnVector solve (MatrixType &typ, const FloatColumnVector& b,
+  FloatComplexColumnVector solve (MatrixType& mattype, const FloatColumnVector& b,
                                   octave_idx_type& info, float& rcon) const;
-  FloatComplexColumnVector solve (MatrixType &typ, const FloatColumnVector& b,
+  FloatComplexColumnVector solve (MatrixType& mattype, const FloatColumnVector& b,
                                   octave_idx_type& info, float& rcon,
                                   solve_singularity_handler sing_handler,
                                   blas_trans_type transt = blas_no_trans) const;
 
-  FloatComplexColumnVector solve (MatrixType &typ,
+  FloatComplexColumnVector solve (MatrixType& mattype,
                                   const FloatComplexColumnVector& b) const;
-  FloatComplexColumnVector solve (MatrixType &typ,
+  FloatComplexColumnVector solve (MatrixType& mattype,
                                   const FloatComplexColumnVector& b,
                                   octave_idx_type& info) const;
-  FloatComplexColumnVector solve (MatrixType &typ,
+  FloatComplexColumnVector solve (MatrixType& mattype,
                                   const FloatComplexColumnVector& b,
                                   octave_idx_type& info, float& rcon) const;
-  FloatComplexColumnVector solve (MatrixType &typ,
+  FloatComplexColumnVector solve (MatrixType& mattype,
                                   const FloatComplexColumnVector& b,
                                   octave_idx_type& info, float& rcon,
                                   solve_singularity_handler sing_handler,
@@ -497,4 +503,3 @@ MM_BOOL_OP_DECLS (FloatComplexMatrix, FloatComplexMatrix, OCTAVE_API)
 MARRAY_FORWARD_DEFS (MArray, FloatComplexMatrix, FloatComplex)
 
 #endif
-
